==> ksaa-2025.4.17.0.tar.gz: ksaa-2025.4.17.0/README.md <==
# Kotone's Auto Assistant 琴音小助手
## 功能
* 自动日常，包括
    * 领取礼物（邮件）
    * 领取活动费
    * 领取工作奖励并自动重新安排工作
    * 竞赛挑战
    * 领取任务奖励
    * 清理商店
        * 包括 AP 商店和金币商店
        * 可以购买推荐商品，或者指定要购买的物品
* 低配版自动培育
    * 支持 REGULAR 和 PRO 模式
    * 支持指定 P 偶像<sup>1</sup>
    * 支持指定使用增强道具（笔记数量和 Pt 数量提升）
    * 暂时**只能使用自动编成**回忆和支援卡
    * 对于非练习周，如果没有推荐休息，暂时只会按顺序执行活动支给（活動支給）、文化课（授業）、外出（おでかけ）、休息这四种，不支持咨询（相談）
    * 领取技能卡和 P 饮料时，固定领取第一个。若 P 饮料溢出，则不领取

<sup>1</sup> 见后文的注意事项

## 安装
### 模拟器要求
* 分辨率：必须是 1280x720
* 系统版本：Android 10+（Q，API 29），这是游戏的要求
* 已开启游戏加速器或代理且网络通畅

### 普通用户
TODO

### 技术用户
琴音小助手通过 pip 分发，因此你可以执行下面的命令来安装：
```bash
# Python == 3.10
pip install ksaa
```

> 琴音小助手的缩写是“kaa”（**K**otone's **A**uto **A**ssist），
> 但是“kaa”已经被其他包占用了，
> 因此改用“ksaa”（**K**otone'**s** **A**uto **A**ssist）。

不过为了避免依赖冲突，你最好使用 pipx 来安装：
```bash
# 安装 pipx
scoop install pipx
pipx ensurepath
# 安装 kaa
pipx install ksaa
```
（也可以通过 pip 安装 pipx，详见 [pipx 文档](https://github.com/pypa/pipx#on-windows)）

如果你不想使用 pipx，也可以手动创建虚拟环境，并使用普通的 pip 安装。

安装完成后，只需要运行 `kaa` 命令即可启动 GUI 界面：
```bash
kaa
```

需要注意的是，配置文件 `config.json` 会自动在工作目录下生成。
因此你最好每次都在同一个地方运行 kaa，否则可能会出现找不到配置文件的情况。

## 使用
### 配置
TODO

### 注意事项
> [!IMPORTANT]
> 建议**使用亲密度至少为 7 的偶像**进行培育，
> 因为琴音小助手暂时无法处理亲密度提升事件。

## 开发
见 [DEVELOPMENT.md](./docs/DEVELOPMENT.md)

## 路线图
下面是待实现的功能：  
（带删除线标记的为已完成）

* 培育
    * 允许指定领取 P 饮料、P 物品、技能卡的领取选择优先级
    * ~~允许指定行动优先级~~
    * 自动使用 P 饮料
    * 支持非凡（アノマリー）属性偶像的自动培育
    * ~~支持琴音的自动培育~~
    * 允许优先选择活动加成高的偶像进行培育
    * 支持 MASTER 培育、NIA 培育
* 竞赛
    * 按分数差距优先选择
* ~~自动硬币扭蛋（コインガシャ）~~
* 调度
    * ~~模拟器启停~~
    * 常驻运行与自动运行
    * 命令行接口
    * 尝试接入 ALAS
* UI
    * 使用 Flet/Flutter 重写 UI
    * 分离脚本与 UI，允许 UI 与脚本分别独立运行
* 启动器
    * 使用 C# 替换当前的简易 .bat 文件
* Linux 支持
* Android 支持
    * 使用 Python for Android 移植 kaa 到 Android 平台
    * 使用 Shizuku 执行 ADB 命令
    * 使用 Pyjnius 绕过 ADB ，使用无障碍直接控制设备
* 开发工具
    * 将开发工具通过 VSCode 扩展与 VSCode 整合

==> ksaa-2025.5.23.3.tar.gz: ksaa-2025.5.23.3/README.md <==
# Kotone's Auto Assistant 琴音小助手
## 功能
* 自动日常，包括
    * 领取礼物（邮件）
    * 领取活动费
    * 领取工作奖励并自动重新安排工作
    * 竞赛挑战
    * 领取任务奖励
    * 清理商店
        * 包括 AP 商店和金币商店
        * 可以购买推荐商品，或者指定要购买的物品
* 低配版自动培育
    * 支持 REGULAR 和 PRO 模式
    * 支持指定 P 偶像<sup>1</sup>
    * 支持指定使用增强道具（笔记数量和 Pt 数量提升）
    * 暂时**只能使用自动编成**回忆和支援卡
    * 对于非练习周，如果没有推荐休息，暂时只会按顺序执行活动支给（活動支給）、文化课（授業）、外出（おでかけ）、休息这四种，不支持咨询（相談）
    * 领取技能卡和 P 饮料时，固定领取第一个。若 P 饮料溢出，则不领取

<sup>1</sup> 见后文的注意事项

## 安装
### 模拟器要求
* 分辨率：必须是 1280x720
* 系统版本：Android 10+（Q，API 29），这是游戏的要求
* 已开启游戏加速器或代理且网络通畅

### 普通用户
TODO

### 技术用户
琴音小助手通过 pip 分发，因此你可以执行下面的命令来安装：
```bash
# Python == 3.10
pip install ksaa
```

> 琴音小助手的缩写是“kaa”（**K**otone's **A**uto **A**ssist），
> 但是“kaa”已经被其他包占用了，
> 因此改用“ksaa”（**K**otone'**s** **A**uto **A**ssist）。

不过为了避免依赖冲突，你最好使用 pipx 来安装：
```bash
# 安装 pipx
scoop install pipx
pipx ensurepath
# 安装 kaa
pipx install ksaa
```
（也可以通过 pip 安装 pipx，详见 [pipx 文档](https://github.com/pypa/pipx#on-windows)）

如果你不想使用 pipx，也可以手动创建虚拟环境，并使用普通的 pip 安装。

安装完成后，只需要运行 `kaa` 命令即可启动 GUI 界面：
```bash
kaa
```

需要注意的是，配置文件 `config.json` 会自动在工作目录下生成。
因此你最好每次都在同一个地方运行 kaa，否则可能会出现找不到配置文件的情况。

## 使用
### 配置
TODO

### 注意事项
> [!IMPORTANT]
> 建议**使用亲密度至少为 7 的偶像**进行培育，
> 因为琴音小助手暂时无法处理亲密度提升事件。

## 开发
见 [DEVELOPMENT.md](./docs/DEVELOPMENT.md)

## 贡献
非常欢迎 PR。

你可以从 Github Issue 中选择一个 Issue 解决，或者从下面的路线图里选一个任务讨论。

## 路线图
下面是待实现的功能：  
（带删除线标记的为已完成）

### 培育
* 允许指定领取 P 饮料、P 物品、技能卡的领取选择优先级
* ~~允许指定行动优先级~~
* 自动使用 P 饮料
* ~~支持非凡（アノマリー）属性偶像的自动培育~~
* ~~支持琴音的自动培育~~
* 允许优先选择活动加成高的偶像进行培育
* ~~支持 MASTER 培育~~
* 支持 NIA 培育

### 日常
* ~~竞赛按分数差距优先选择~~
* ~~自动硬币扭蛋（コインガシャ）~~

### 调度
* ~~模拟器启停~~
* 记录任务执行时间与次数，避免重复执行。例如竞赛每天只执行一次
* 常驻运行与自动运行
* ~~命令行接口~~
* 尝试接入 ALAS

### UI
* UI
    * 使用 Flet/Flutter 重写 UI
    * 分离脚本与 UI，允许 UI 与脚本分别独立运行
* 启动器
    * 使用 C# 替换当前的简易 .bat 文件

### 跨平台
* Android 支持
  - [ ] 使用 Python for Android 移植 kaa 到 Android 平台
    - [ ] 解决 native 依赖编译问题
    - [ ] 需要一个适合移动端的 UI
  - [ ] 调用 Shizuku 执行 ADB 命令
  - [ ] 使用 Pyjnius 绕过 ADB ，调用无障碍直接控制设备
* Linux 支持

### 开发工具
* 使用 Konva.js 重构 ImageAnnotation 工具
* 将开发工具通过 VSCode 扩展与 VSCode 整合

### 其他
* 适配汉化版
  - [ ] 需要一个合适的方法自动切换不用语言的资源文件
  - [ ] 需要一个合适的工具来辅助替换模板图片文件
  - [ ] 收集汉化版本的截图
